'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

const path = require('path');
const loadConfiguration = require('./utils/loadConfiguration');

class Environment {

  constructor(cwd, configFileName = '.app.js', logger) {
    this.cwd = cwd;
    this.configFileName = configFileName;
    this.logger = logger;
  }

  configFilePath() {
    return path.resolve(this.cwd, this.configFileName);
  }

  getConfiguration() {
    return loadConfiguration(this);
  }

  getName() {
    return this.getConfiguration().env.NODE_ENV;
  }

  build() {
    var _this = this;

    return _asyncToGenerator(function* () {
      const config = loadConfiguration(_this);

      // run build phase on plugins (do not instantiate them)
      const pluginControllers = yield Promise.all(config.plugins.map(function (plugin) {
        return plugin(_this, true, _this.logger);
      }));

      yield Promise.all(pluginControllers.map(function (pluginController) {
        return pluginController.build();
      }));
    })();
  }

  start() {
    var _this2 = this;

    return _asyncToGenerator(function* () {
      const config = loadConfiguration(_this2);

      // instantiate plugins
      _this2.plugins = yield Promise.all(config.plugins.map(function (plugin) {
        return plugin(_this2, false, _this2.logger);
      }));

      yield Promise.all(_this2.plugins.map(function (p) {
        return p.start();
      }));
    })();
  }

  restart() {
    var _this3 = this;

    return _asyncToGenerator(function* () {
      // terminate all plugins
      yield Promise.all(_this3.plugins.map(function (pluginController) {
        return pluginController.terminate();
      }));

      // start all plugins
      yield _this3.start();
    })();
  }

  stop() {
    var _this4 = this;

    return _asyncToGenerator(function* () {
      yield Promise.all(_this4.plugins.map(function (pluginController) {
        return pluginController.terminate();
      }));
    })();
  }
}

module.exports = Environment;