'use strict';

const chalk = require('chalk');

class LogGroup {

  constructor(name, logger) {
    this.name = name;
    this.logger = logger;
    this.messages = [];
  }

  clear() {
    this.messages = [];
    this.logger.render();
  }

  log(message) {
    this.messages.push(message);
    this.logger.render();
  }

  info(message) {
    this.log(chalk.cyan(message));
  }

  success(message) {
    this.log(chalk.green(message));
  }

  warning(message) {
    this.log(chalk.yellow(message));
  }

  error(message) {
    this.log(chalk.red(message));
  }

  getMessages() {
    return this.messages;
  }

  getName() {
    return this.name;
  }

  remove() {
    this.logger.removeGroup(this.name);
  }
}

module.exports = LogGroup;