'use strict';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

const chokidar = require('chokidar');
const path = require('path');

function createUpdater(env, logger) {
  return filePath => {
    // eslint-disable-line no-unused-vars
    logger.clear();
    logger.info('Detected change in configuration file, restarting environment...');
    // restart environment (terminates all plugins and loads them again)
    env.restart();
  };
}

/**
 * Watches configuration file and restarts build on change
 *
 * @param {Object} env
 * @param {boolean} runOnce   run only once (used in build script)
 * @param {Logger} logger
 */
const plugin = (env, runOnce = false, logger) => {
  let logGroup;
  let watcher;

  return {
    build() {
      return _asyncToGenerator(function* () {
        return Promise.resolve();
      })();
    },

    start() {
      return _asyncToGenerator(function* () {
        return new Promise(function (resolve, reject) {
          logGroup = logger.createGroup('watch configuration');
          const updater = createUpdater(env, logGroup);

          logGroup.clear();

          // start chokidar and watch for .app.js changes
          // everytime configuration changes, restart whole build
          watcher = chokidar.watch(`${ path.resolve(env.cwd, './.app.js') }`, {
            cwd: env.cwd
          });

          watcher.on('ready', function () {
            ['add', 'change', 'unlink'].forEach(function (event) {
              return watcher.on(event, updater);
            });
            resolve();
          });

          watcher.on('error', function (error) {
            logGroup.clear();
            logGroup.error('Watch configuration plugin failed');
            logGroup.error(error);

            reject(error);
          });
        });
      })();
    },

    terminate() {
      return _asyncToGenerator(function* () {
        logGroup.remove();
        watcher.close();
      })();
    }
  };
};

module.exports = plugin;